@@ -3,7 +3,7 @@ from pathlib import Path
 from datetime import datetime
 
 class logger:
-    def __init__(self, log_filepath=None, max_lines=100_000, level='info', name=None, log_to_file=False):
+    def __init__(self, log_filepath=None, max_lines=100_000, level='info', name=None, log_to_file=True):
         filename = Path(sys.argv[0]).stem
         self.filename = filename
         if not log_filepath:
@@ -56,8 +56,6 @@ class logger:
             self.logger.error(message)
         elif level == 'debug':
             self.logger.debug(message)
-        elif level == 'success':
-            self.logger.success(message)
         elif level == 'warning':
             self.logger.warning(message)
 
@@ -156,6 +154,9 @@ class printr:
     def __init__(self, *items, same_line=False, current_time=False, check_for_log=True, level='info', beautify=True):
         print(*items, same_line=same_line, current_time=current_time, check_for_log=check_for_log, level=level, beautify=beautify)
 
+# from rich.pretty import pretty_repr
+# from rich.text import Text
+
 def prettify(items, beautify):
     message = ''
     for item in items:
